@@ -62,7 +62,7 @@ int eraUt1utc(double ut11, double ut12, double dut1,
 **     Explanatory Supplement to the Astronomical Almanac,
 **     P. Kenneth Seidelmann (ed), University Science Books (1992)
 **
-**  Copyright (C) 2013-2015, NumFOCUS Foundation.
+**  Copyright (C) 2013-2019, NumFOCUS Foundation.
 **  Derived, with permission, from the SOFA library.  See notes at end of file.
 */
 {
@@ -70,11 +70,12 @@ int eraUt1utc(double ut11, double ut12, double dut1,
    int i, iy, im, id, js;
    double duts, u1, u2, d1, dats1, d2, fd, dats2, ddats, us1, us2, du;
 
+
 /* UT1-UTC in seconds. */
    duts = dut1;
 
 /* Put the two parts of the UT1 into big-first order. */
-   big1 = ( ut11 >= ut12 );
+   big1 = ( fabs(ut11) >= fabs(ut12) );
    if ( big1 ) {
       u1 = ut11;
       u2 = ut12;
@@ -140,7 +141,7 @@ int eraUt1utc(double ut11, double ut12, double dut1,
 /*----------------------------------------------------------------------
 **  
 **  
-**  Copyright (C) 2013-2015, NumFOCUS Foundation.
+**  Copyright (C) 2013-2019, NumFOCUS Foundation.
 **  All rights reserved.
 **  
 **  This library is derived, with permission, from the International
